@@ -4,11 +4,16 @@ import json
 
 import awesomeTaskPy
 from awesomeTaskPy.context.context import context
+from awesomeTaskPy.context.event import event
 import time
 import sys
 import traceback
+import os
 
+#当前执行过后的任务ID
 taskIds = []
+#当前执行任务之后的执行结果
+taskExecuteResult = {}
 class baseTask():
     __taskInfo = None
     __loger = None
@@ -23,6 +28,9 @@ class baseTask():
         return int(time.time())
 
     def __init__(self, taskInfo, modulePath):
+        def ON_CHILDREN_TASK_FINISHED_HANDLER(params):
+            taskExecuteResult[params['taskId']]=params
+        event.register("ON_CHILDREN_TASK_FINISHED",ON_CHILDREN_TASK_FINISHED_HANDLER)
         self.__taskInfo = taskInfo
         self.__modulePath = modulePath
         self.__startAt = self.__now()
@@ -52,6 +60,7 @@ class baseTask():
             }
             # 回调返回值并且情况缓冲的日志
             awesomeTaskPy.context.context.getContext().getLoger().writeRes(output).flushTmpLog()
+        os._exit(1)
     def log(self, message):
         return  awesomeTaskPy.context.context.getContext().getLoger().write(message)
 
@@ -79,11 +88,35 @@ class baseTask():
             "fun":fun.__name__,
             "input":args,
             "project_name":contextObj.getTaskInfo()["project_name"],
+            "pTaskId":contextObj.getTaskInfo()['uniqueTaskId'],
             "taskId":childrenTaskId
         }
         taskIds.append(childrenTaskId)
         contextObj.getQueue().send(RPC)
+        contextObj.getQueue().startRecv()
         return childrenTaskId
+    ##获取任务执行的结果
+    ##由于是异步执行 这里会等待执行结果并且返回
+    @staticmethod
+    def awaitTask(taskId,timeout,defaultSleepSecond=0.05):
+        if defaultSleepSecond<=0:
+            raise Exception("defaultSleepSecond must more than zero")
+        waitTime = 0
+        while(taskId not in taskExecuteResult.keys()):
+            if waitTime>timeout:
+                raise Exception("remote apply failed cause timeout")
+            waitTime+=defaultSleepSecond
+            time.sleep(defaultSleepSecond)
+            continue
+        return taskExecuteResult[taskId]
+    ##获取当前执行的进程 执行进度
+    @staticmethod
+    def remoteProcess():
+        return {
+            "process":len(taskExecuteResult.keys())/len(taskIds),
+            "show":str(len(taskExecuteResult.keys()))+"/"+str(len(taskIds))
+        }
+
 
 def outputAndFork(output):
     return awesomeTaskPy.context.context.getContext().getLoger().writeOutputAndFork(output)
